@@ -69,7 +69,6 @@ public class LocaleNames_cs extends OpenListResourceBundle {
         final String metaValue_ccp = "\u010dakma";
         final String metaValue_kpe = "kpelle";
         final String metaValue_nqo = "n\u2019ko";
-        final String metaValue_vai = "vai";
         final Object[][] data = new Object[][] {
             { "001", "sv\u011bt" },
             { "002", "Afrika" },
@@ -601,6 +600,7 @@ public class LocaleNames_cs extends OpenListResourceBundle {
             { "bjn", "band\u017ear\u0161tina" },
             { "bkm", "kom" },
             { "bla", "siksika" },
+            { "blo", "anii\u0161tina" },
             { "bpy", "bi\u0161nuprijskomanipur\u0161tina" },
             { "bqi", "bachtij\u00e1r\u0161tina" },
             { "bra", "brad\u017e\u0161tina" },
@@ -691,7 +691,6 @@ public class LocaleNames_cs extends OpenListResourceBundle {
             { "glk", "gila\u010dtina" },
             { "gmh", "hornon\u011bm\u010dina (st\u0159edov\u011bk\u00e1)" },
             { "goh", "hornon\u011bm\u010dina (star\u00e1)" },
-            { "gom", "konk\u00e1n\u0161tina (Goa)" },
             { "gon", "g\u00f3nd\u0161tina" },
             { "gor", "gorontalo" },
             { "got", "g\u00f3t\u0161tina" },
@@ -764,6 +763,7 @@ public class LocaleNames_cs extends OpenListResourceBundle {
             { "kum", "kumy\u010dtina" },
             { "kut", "kutenaj\u0161tina" },
             { "kwk", "kvakiut\u0161tina" },
+            { "kxv", "k\u00favi" },
             { "lad", "ladin\u0161tina" },
             { "lag", "langi" },
             { "lah", "lahnd\u0161tina" },
@@ -963,11 +963,11 @@ public class LocaleNames_cs extends OpenListResourceBundle {
             { "uga", "ugarit\u0161tina" },
             { "umb", "umbundu" },
             { "und", "nezn\u00e1m\u00fd jazyk" },
-            { "vai", metaValue_vai },
             { "vec", "ben\u00e1t\u0161tina" },
             { "vep", "vep\u0161tina" },
             { "vls", "vl\u00e1m\u0161tina (z\u00e1padn\u00ed)" },
             { "vmf", "n\u011bm\u010dina (mohansko-fransk\u00e9 dialekty)" },
+            { "vmw", "makhuw\u0161tina" },
             { "vot", "vot\u0161tina" },
             { "vro", "v\u00f5ru\u0161tina" },
             { "vun", "vunjo" },
@@ -979,6 +979,7 @@ public class LocaleNames_cs extends OpenListResourceBundle {
             { "wuu", "\u010d\u00edn\u0161tina (dialekty Wu)" },
             { "xal", "kalmy\u010dtina" },
             { "xmf", "mingrel\u0161tina" },
+            { "xnr", "k\u00e1ngr\u00ed" },
             { "xog", "sog\u0161tina" },
             { "yao", "jao\u0161tina" },
             { "yap", "jap\u0161tina" },
@@ -1153,7 +1154,7 @@ public class LocaleNames_cs extends OpenListResourceBundle {
             { "Tibt", "tibetsk\u00e9" },
             { "Tirh", "tirhuta" },
             { "Ugar", "ugaritsk\u00e9 kl\u00ednov\u00e9" },
-            { "Vaii", metaValue_vai },
+            { "Vaii", "vai" },
             { "Visp", "viditeln\u00e1 \u0159e\u010d" },
             { "Wara", "varang k\u0161iti" },
             { "Wole", "karol\u00ednsk\u00e9 (woleai)" },
